@@ -76,7 +76,7 @@ def generate_file(graph, target_column, task_type, colab=False):
             elif steps_list[i] == "evaluate_model":
                 f.write(
                     # TODO: make changes for clustering
-                    f"\tmetrics = huble.sklearn.evaluate_model(model=Model, training_dataset=training_dataset, test_dataset=test_dataset, target_column= '{target_column}', task_type='{task_type}' )"
+                    f"\tmetrics, feature_importance_dict = huble.sklearn.evaluate_model(model=Model, training_dataset=training_dataset, test_dataset=test_dataset, target_column= '{target_column}', task_type='{task_type}' )"
                 )
                 f.write("\n")
             elif steps_list[i] == "primary_dataset":
