@@ -27,6 +27,6 @@ from .functions import (
     spectral,
     affinity_propogation,
     optics,
-    dbscan
+    dbscan,
 )
 from .handler import *
